========
gleandoc
========


.. image:: https://img.shields.io/pypi/v/gleandoc.svg
        :target: https://pypi.python.org/pypi/gleandoc

.. image:: https://img.shields.io/travis/datagazing/gleandoc.svg
        :target: https://travis-ci.com/datagazing/gleandoc

.. image:: https://readthedocs.org/projects/gleandoc/badge/?version=latest
        :target: https://gleandoc.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status



Simple convenience function to extract docstring

Examples
--------

Print the first line of a docstring:

.. code-block:: python

  >>> import gleandoc
  >>> docstring = gleandoc.docstring('re')
  >>> docstring.splitlines()[0]
  'Support for regular expressions (RE).'
  >>>

Do the same thing from the command line:

.. code-block:: console

  $ gleandoc re | head -1
  Support for regular expressions (RE).
  $

Features
--------

* No dependencies

Limitations
-----------

* Embedded backslash-n newlines are treated as actual newlines
* Relies on various pseudo-internals: locals(), exec()



Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
